@@ -16,13 +16,15 @@
 # under the License.
 from __future__ import annotations
 
-from typing import Any
+from typing import Any, Callable
 
 from airflow.decorators.base import TaskDecorator
 from airflow.decorators.branch_python import branch_task
 from airflow.decorators.external_python import external_python_task
 from airflow.decorators.python import python_task
 from airflow.decorators.python_virtualenv import virtualenv_task
+from airflow.decorators.sensor import sensor_task
+from airflow.decorators.setup_teardown import setup_task, teardown_task
 from airflow.decorators.short_circuit import short_circuit_task
 from airflow.decorators.task_group import task_group
 from airflow.models.dag import dag
@@ -40,6 +42,9 @@ __all__ = [
     "external_python_task",
     "branch_task",
     "short_circuit_task",
+    "sensor_task",
+    "setup",
+    "teardown",
 ]
 
 
@@ -51,6 +56,7 @@ class TaskDecoratorCollection:
     external_python = staticmethod(external_python_task)
     branch = staticmethod(branch_task)
     short_circuit = staticmethod(short_circuit_task)
+    sensor = staticmethod(sensor_task)
 
     __call__: Any = python  # Alias '@task' to '@task.python'.
 
@@ -65,3 +71,5 @@ class TaskDecoratorCollection:
 
 
 task = TaskDecoratorCollection()
+setup: Callable = setup_task
+teardown: Callable = teardown_task
