@@ -15,8 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """Example DAG demonstrating the usage of the BashOperator."""
+from __future__ import annotations
 
 import datetime
 
@@ -24,25 +24,25 @@ import pendulum
 
 from airflow import DAG
 from airflow.operators.bash import BashOperator
-from airflow.operators.dummy import DummyOperator
+from airflow.operators.empty import EmptyOperator
 
 with DAG(
-    dag_id='example_bash_operator',
-    schedule_interval='0 0 * * *',
+    dag_id="example_bash_operator",
+    schedule="0 0 * * *",
     start_date=pendulum.datetime(2021, 1, 1, tz="UTC"),
     catchup=False,
     dagrun_timeout=datetime.timedelta(minutes=60),
-    tags=['example', 'example2'],
+    tags=["example", "example2"],
     params={"example_key": "example_value"},
 ) as dag:
-    run_this_last = DummyOperator(
-        task_id='run_this_last',
+    run_this_last = EmptyOperator(
+        task_id="run_this_last",
     )
 
     # [START howto_operator_bash]
     run_this = BashOperator(
-        task_id='run_after_loop',
-        bash_command='echo 1',
+        task_id="run_after_loop",
+        bash_command="echo 1",
     )
     # [END howto_operator_bash]
 
@@ -50,22 +50,22 @@ with DAG(
 
     for i in range(3):
         task = BashOperator(
-            task_id='runme_' + str(i),
+            task_id=f"runme_{i}",
             bash_command='echo "{{ task_instance_key_str }}" && sleep 1',
         )
         task >> run_this
 
     # [START howto_operator_bash_template]
     also_run_this = BashOperator(
-        task_id='also_run_this',
-        bash_command='echo "run_id={{ run_id }} | dag_run={{ dag_run }}"',
+        task_id="also_run_this",
+        bash_command='echo "ti_key={{ task_instance_key_str }}"',
     )
     # [END howto_operator_bash_template]
     also_run_this >> run_this_last
 
 # [START howto_operator_bash_skip]
 this_will_skip = BashOperator(
-    task_id='this_will_skip',
+    task_id="this_will_skip",
     bash_command='echo "hello world"; exit 99;',
     dag=dag,
 )
@@ -73,4 +73,4 @@ this_will_skip = BashOperator(
 this_will_skip >> run_this_last
 
 if __name__ == "__main__":
-    dag.cli()
+    dag.test()
