@@ -22,10 +22,7 @@ virtual environment.
 from __future__ import annotations
 
 import logging
-import os
-import shutil
 import sys
-import tempfile
 import time
 from pprint import pprint
 
@@ -33,19 +30,23 @@ import pendulum
 
 from airflow import DAG
 from airflow.decorators import task
+from airflow.operators.python import ExternalPythonOperator, PythonVirtualenvOperator, is_venv_installed
 
 log = logging.getLogger(__name__)
 
-PYTHON = sys.executable
+PATH_TO_PYTHON_BINARY = sys.executable
+
+
+def x():
+    pass
 
-BASE_DIR = tempfile.gettempdir()
 
 with DAG(
-    dag_id='example_python_operator',
+    dag_id="example_python_operator",
     schedule=None,
     start_date=pendulum.datetime(2021, 1, 1, tz="UTC"),
     catchup=False,
-    tags=['example'],
+    tags=["example"],
 ) as dag:
 
     # [START howto_operator_python]
@@ -54,7 +55,7 @@ with DAG(
         """Print the Airflow context and ds variable from the context."""
         pprint(kwargs)
         print(ds)
-        return 'Whatever you return gets printed in the logs'
+        return "Whatever you return gets printed in the logs"
 
     run_this = print_context()
     # [END howto_operator_python]
@@ -71,17 +72,17 @@ with DAG(
     # Generate 5 sleeping tasks, sleeping from 0.0 to 0.4 seconds respectively
     for i in range(5):
 
-        @task(task_id=f'sleep_for_{i}')
+        @task(task_id=f"sleep_for_{i}")
         def my_sleeping_function(random_base):
             """This is a function that will run within the DAG execution"""
             time.sleep(random_base)
 
-        sleeping_task = my_sleeping_function(random_base=float(i) / 10)
+        sleeping_task = my_sleeping_function(random_base=i / 10)
 
         run_this >> log_the_sql >> sleeping_task
     # [END howto_operator_python_kwargs]
 
-    if not shutil.which("virtualenv"):
+    if not is_venv_installed():
         log.warning("The virtalenv_python example task requires virtualenv, please install it.")
     else:
         # [START howto_operator_python_venv]
@@ -99,14 +100,14 @@ with DAG(
 
             from colorama import Back, Fore, Style
 
-            print(Fore.RED + 'some red text')
-            print(Back.GREEN + 'and with a green background')
-            print(Style.DIM + 'and in dim text')
+            print(Fore.RED + "some red text")
+            print(Back.GREEN + "and with a green background")
+            print(Style.DIM + "and in dim text")
             print(Style.RESET_ALL)
             for _ in range(4):
-                print(Style.DIM + 'Please wait...', flush=True)
+                print(Style.DIM + "Please wait...", flush=True)
                 sleep(1)
-            print('Finished')
+            print("Finished")
 
         virtualenv_task = callable_virtualenv()
         # [END howto_operator_python_venv]
@@ -114,7 +115,7 @@ with DAG(
         sleeping_task >> virtualenv_task
 
         # [START howto_operator_external_python]
-        @task.external_python(task_id="external_python", python=os.fspath(sys.executable))
+        @task.external_python(task_id="external_python", python=PATH_TO_PYTHON_BINARY)
         def callable_external_python():
             """
             Example function that will be performed in a virtual environment.
@@ -128,11 +129,27 @@ with DAG(
             print(f"Running task via {sys.executable}")
             print("Sleeping")
             for _ in range(4):
-                print('Please wait...', flush=True)
+                print("Please wait...", flush=True)
                 sleep(1)
-            print('Finished')
+            print("Finished")
 
         external_python_task = callable_external_python()
         # [END howto_operator_external_python]
 
-        run_this >> external_python_task
+        # [START howto_operator_external_python_classic]
+        external_classic = ExternalPythonOperator(
+            task_id="external_python_classic",
+            python=PATH_TO_PYTHON_BINARY,
+            python_callable=x,
+        )
+        # [END howto_operator_external_python_classic]
+
+        # [START howto_operator_python_venv_classic]
+        virtual_classic = PythonVirtualenvOperator(
+            task_id="virtualenv_classic",
+            requirements="colorama==0.4.0",
+            python_callable=x,
+        )
+        # [END howto_operator_python_venv_classic]
+
+        run_this >> external_classic >> external_python_task >> virtual_classic
