@@ -17,13 +17,19 @@
 # under the License.
 # Note: Any AirflowException raised is expected to cause the TaskInstance
 #       to be marked in an ERROR state
-"""Exceptions used by Airflow"""
+"""Exceptions used by Airflow."""
 from __future__ import annotations
 
-import datetime
 import warnings
 from http import HTTPStatus
-from typing import Any, NamedTuple, Sized
+from typing import TYPE_CHECKING, Any, NamedTuple, Sized
+
+from airflow.utils.trigger_rule import TriggerRule
+
+if TYPE_CHECKING:
+    import datetime
+
+    from airflow.models import DAG, DagRun
 
 
 class AirflowException(Exception):
@@ -81,7 +87,7 @@ class AirflowWebServerTimeout(AirflowException):
 
 
 class AirflowSkipException(AirflowException):
-    """Raise when the task should be skipped"""
+    """Raise when the task should be skipped."""
 
 
 class AirflowFailException(AirflowException):
@@ -166,6 +172,14 @@ class AirflowClusterPolicyViolation(AirflowException):
     """Raise when there is a violation of a Cluster Policy in DAG definition."""
 
 
+class AirflowClusterPolicySkipDag(AirflowException):
+    """Raise when skipping dag is needed in Cluster Policy."""
+
+
+class AirflowClusterPolicyError(AirflowException):
+    """Raise for a Cluster Policy other than AirflowClusterPolicyViolation or AirflowClusterPolicySkipDag."""
+
+
 class AirflowTimetableInvalid(AirflowException):
     """Raise when a DAG has an invalid timetable."""
 
@@ -185,6 +199,12 @@ class DagRunNotFound(AirflowNotFoundException):
 class DagRunAlreadyExists(AirflowBadRequest):
     """Raise when creating a DAG run for DAG which already has DAG run entry."""
 
+    def __init__(self, dag_run: DagRun, execution_date: datetime.datetime, run_id: str) -> None:
+        super().__init__(
+            f"A DAG Run already exists for DAG {dag_run.dag_id} at {execution_date} with run id {run_id}"
+        )
+        self.dag_run = dag_run
+
 
 class DagFileExists(AirflowBadRequest):
     """Raise when a DAG ID is still in DagBag i.e., DAG file is in DAG folder."""
@@ -194,6 +214,25 @@ class DagFileExists(AirflowBadRequest):
         warnings.warn("DagFileExists is deprecated and will be removed.", DeprecationWarning, stacklevel=2)
 
 
+class FailStopDagInvalidTriggerRule(AirflowException):
+    """Raise when a dag has 'fail_stop' enabled yet has a non-default trigger rule."""
+
+    _allowed_rules = (TriggerRule.ALL_SUCCESS, TriggerRule.ALL_DONE_SETUP_SUCCESS)
+
+    @classmethod
+    def check(cls, *, dag: DAG | None, trigger_rule: TriggerRule):
+        """
+        Check that fail_stop dag tasks have allowable trigger rules.
+
+        :meta private:
+        """
+        if dag is not None and dag.fail_stop and trigger_rule not in cls._allowed_rules:
+            raise cls()
+
+    def __str__(self) -> str:
+        return f"A 'fail-stop' dag can only have {TriggerRule.ALL_SUCCESS} trigger rule"
+
+
 class DuplicateTaskIdFound(AirflowException):
     """Raise when a Task with duplicate task_id is defined in the same DAG."""
 
@@ -216,11 +255,11 @@ class TaskAlreadyInTaskGroup(AirflowException):
 
 
 class SerializationError(AirflowException):
-    """A problem occurred when trying to serialize a DAG."""
+    """A problem occurred when trying to serialize something."""
 
 
 class ParamValidationError(AirflowException):
-    """Raise when DAG params is invalid"""
+    """Raise when DAG params is invalid."""
 
 
 class TaskNotFound(AirflowNotFoundException):
@@ -308,6 +347,8 @@ class ConnectionNotUnique(AirflowException):
 
 class TaskDeferred(BaseException):
     """
+    Signal an operator moving to deferred state.
+
     Special exception raised to signal that the operator it was raised from
     wishes to defer until a trigger fires.
     """
@@ -337,8 +378,28 @@ class TaskDeferralError(AirflowException):
     """Raised when a task failed during deferral for some reason."""
 
 
-class PodReconciliationError(AirflowException):
-    """Raised when an error is encountered while trying to merge pod configs."""
+# The try/except handling is needed after we moved all k8s classes to cncf.kubernetes provider
+# These two exceptions are used internally by Kubernetes Executor but also by PodGenerator, so we need
+# to leave them here in case older version of cncf.kubernetes provider is used to run KubernetesPodOperator
+# and it raises one of those exceptions. The code should be backwards compatible even if you import
+# and try/except the exception using direct imports from airflow.exceptions.
+# 1) if you have old provider, both provider and pod generator will throw the "airflow.exceptions" exception.
+# 2) if you have new provider, both provider and pod generator will throw the
+#    "airflow.providers.cncf.kubernetes" as it will be imported here from the provider.
+try:
+    from airflow.providers.cncf.kubernetes.executors.kubernetes_executor import PodMutationHookException
+except ImportError:
+
+    class PodMutationHookException(AirflowException):  # type: ignore[no-redef]
+        """Raised when exception happens during Pod Mutation Hook execution."""
+
+
+try:
+    from airflow.providers.cncf.kubernetes.executors.kubernetes_executor import PodReconciliationError
+except ImportError:
+
+    class PodReconciliationError(AirflowException):  # type: ignore[no-redef]
+        """Raised when an error is encountered while trying to merge pod configs."""
 
 
 class RemovedInAirflow3Warning(DeprecationWarning):
@@ -353,3 +414,13 @@ class AirflowProviderDeprecationWarning(DeprecationWarning):
 
     deprecated_provider_since: str | None = None
     "Indicates the provider version that started raising this deprecation warning"
+
+
+class DeserializingResultError(ValueError):
+    """Raised when an error is encountered while a pickling library deserializes a pickle file."""
+
+    def __str__(self):
+        return (
+            "Error deserializing result. Note that result deserialization "
+            "is not supported across major Python versions. Cause: " + str(self.__cause__)
+        )
