@@ -15,7 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
+from __future__ import annotations
+
 # Licensed to Cloudera, Inc. under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -31,25 +32,24 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Kerberos security provider"""
+"""Kerberos security provider."""
 import logging
 import shlex
 import subprocess
 import sys
 import time
-from typing import List, Optional
 
 from airflow.configuration import conf
 from airflow.utils.net import get_hostname
 
-NEED_KRB181_WORKAROUND = None  # type: Optional[bool]
+NEED_KRB181_WORKAROUND: bool | None = None
 
 log = logging.getLogger(__name__)
 
 
-def renew_from_kt(principal: Optional[str], keytab: str, exit_on_fail: bool = True):
+def renew_from_kt(principal: str | None, keytab: str, exit_on_fail: bool = True):
     """
-    Renew kerberos token from keytab
+    Renew kerberos token from keytab.
 
     :param principal: principal
     :param keytab: keytab file
@@ -59,22 +59,22 @@ def renew_from_kt(principal: Optional[str], keytab: str, exit_on_fail: bool = Tr
     # minutes to give ourselves a large renewal buffer.
     renewal_lifetime = f"{conf.getint('kerberos', 'reinit_frequency')}m"
 
-    cmd_principal = principal or conf.get_mandatory_value('kerberos', 'principal').replace(
+    cmd_principal = principal or conf.get_mandatory_value("kerberos", "principal").replace(
         "_HOST", get_hostname()
     )
 
-    if conf.getboolean('kerberos', 'forwardable'):
-        forwardable = '-f'
+    if conf.getboolean("kerberos", "forwardable"):
+        forwardable = "-f"
     else:
-        forwardable = '-F'
+        forwardable = "-F"
 
-    if conf.getboolean('kerberos', 'include_ip'):
-        include_ip = '-a'
+    if conf.getboolean("kerberos", "include_ip"):
+        include_ip = "-a"
     else:
-        include_ip = '-A'
+        include_ip = "-A"
 
-    cmdv: List[str] = [
-        conf.get_mandatory_value('kerberos', 'kinit_path'),
+    cmdv: list[str] = [
+        conf.get_mandatory_value("kerberos", "kinit_path"),
         forwardable,
         include_ip,
         "-r",
@@ -83,7 +83,7 @@ def renew_from_kt(principal: Optional[str], keytab: str, exit_on_fail: bool = Tr
         "-t",
         keytab,  # specify keytab
         "-c",
-        conf.get_mandatory_value('kerberos', 'ccache'),  # specify credentials cache
+        conf.get_mandatory_value("kerberos", "ccache"),  # specify credentials cache
         cmd_principal,
     ]
     log.info("Re-initialising kerberos from keytab: %s", " ".join(shlex.quote(f) for f in cmdv))
@@ -99,7 +99,7 @@ def renew_from_kt(principal: Optional[str], keytab: str, exit_on_fail: bool = Tr
         subp.wait()
         if subp.returncode != 0:
             log.error(
-                "Couldn't reinit from keytab! `kinit' exited with %s.\n%s\n%s",
+                "Couldn't reinit from keytab! `kinit` exited with %s.\n%s\n%s",
                 subp.returncode,
                 "\n".join(subp.stdout.readlines() if subp.stdout else []),
                 "\n".join(subp.stderr.readlines() if subp.stderr else []),
@@ -131,10 +131,10 @@ def perform_krb181_workaround(principal: str):
     :param principal: principal name
     :return: None
     """
-    cmdv: List[str] = [
-        conf.get_mandatory_value('kerberos', 'kinit_path'),
+    cmdv: list[str] = [
+        conf.get_mandatory_value("kerberos", "kinit_path"),
         "-c",
-        conf.get_mandatory_value('kerberos', 'ccache'),
+        conf.get_mandatory_value("kerberos", "ccache"),
         "-R",
     ]  # Renew ticket_cache
 
@@ -144,7 +144,7 @@ def perform_krb181_workaround(principal: str):
 
     if ret != 0:
         principal = f"{principal or conf.get('kerberos', 'principal')}/{get_hostname()}"
-        ccache = conf.get('kerberos', 'ccache')
+        ccache = conf.get("kerberos", "ccache")
         log.error(
             "Couldn't renew kerberos ticket in order to work around Kerberos 1.8.1 issue. Please check that "
             "the ticket for '%s' is still renewable:\n  $ kinit -f -c %s\nIf the 'renew until' date is the "
@@ -159,21 +159,24 @@ def perform_krb181_workaround(principal: str):
 
 
 def detect_conf_var() -> bool:
-    """Return true if the ticket cache contains "conf" information as is found
+    """
+    Autodetect the Kerberos ticket configuration.
+
+    Return true if the ticket cache contains "conf" information as is found
     in ticket caches of Kerberos 1.8.1 or later. This is incompatible with the
     Sun Java Krb5LoginModule in Java6, so we need to take an action to work
     around it.
     """
-    ticket_cache = conf.get_mandatory_value('kerberos', 'ccache')
+    ticket_cache = conf.get_mandatory_value("kerberos", "ccache")
 
-    with open(ticket_cache, 'rb') as file:
+    with open(ticket_cache, "rb") as file:
         # Note: this file is binary, so we check against a bytearray.
-        return b'X-CACHECONF:' in file.read()
+        return b"X-CACHECONF:" in file.read()
 
 
-def run(principal: Optional[str], keytab: str):
+def run(principal: str | None, keytab: str):
     """
-    Run the kerbros renewer.
+    Run the kerberos renewer.
 
     :param principal: principal name
     :param keytab: keytab file
@@ -185,4 +188,4 @@ def run(principal: Optional[str], keytab: str):
 
     while True:
         renew_from_kt(principal, keytab)
-        time.sleep(conf.getint('kerberos', 'reinit_frequency'))
+        time.sleep(conf.getint("kerberos", "reinit_frequency"))
