@@ -30,6 +30,11 @@ class TimeSensor(BaseSensorOperator):
     Waits until the specified time of the day.
 
     :param target_time: time after which the job succeeds
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/operator:TimeSensor`
+
     """
 
     def __init__(self, *, target_time, **kwargs):
@@ -37,16 +42,21 @@ class TimeSensor(BaseSensorOperator):
         self.target_time = target_time
 
     def poke(self, context: Context):
-        self.log.info('Checking if the time (%s) has come', self.target_time)
+        self.log.info("Checking if the time (%s) has come", self.target_time)
         return timezone.make_naive(timezone.utcnow(), self.dag.timezone).time() > self.target_time
 
 
 class TimeSensorAsync(BaseSensorOperator):
     """
-    Waits until the specified time of the day, freeing up a worker slot while
-    it is waiting.
+    Waits until the specified time of the day.
+
+    This frees up a worker slot while it is waiting.
 
     :param target_time: time after which the job succeeds
+
+    .. seealso::
+        For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/operator:TimeSensorAsync`
     """
 
     def __init__(self, *, target_time, **kwargs):
@@ -54,17 +64,18 @@ class TimeSensorAsync(BaseSensorOperator):
         self.target_time = target_time
 
         aware_time = timezone.coerce_datetime(
-            datetime.datetime.combine(datetime.datetime.today(), self.target_time)
+            datetime.datetime.combine(datetime.datetime.today(), self.target_time, self.dag.timezone)
         )
 
         self.target_datetime = timezone.convert_to_utc(aware_time)
 
     def execute(self, context: Context):
+        trigger = DateTimeTrigger(moment=self.target_datetime)
         self.defer(
-            trigger=DateTimeTrigger(moment=self.target_datetime),
+            trigger=trigger,
             method_name="execute_complete",
         )
 
     def execute_complete(self, context, event=None):
-        """Callback for when the trigger fires - returns immediately."""
+        """Execute when the trigger fires - returns immediately."""
         return None
