@@ -17,18 +17,23 @@
 from __future__ import annotations
 
 import itertools
-from typing import Iterable
+from typing import TYPE_CHECKING, Iterable
 
 import pendulum
-from pendulum import DateTime
 
-from airflow.timetables.base import DagRunInfo, DataInterval, TimeRestriction, Timetable
+from airflow.timetables.base import DagRunInfo, DataInterval, Timetable
+
+if TYPE_CHECKING:
+    from pendulum import DateTime
+
+    from airflow.timetables.base import TimeRestriction
 
 
 class EventsTimetable(Timetable):
     """
-    Timetable that schedules DAG runs at specific listed datetimes. Suitable for
-    predictable but truly irregular scheduling such as sporting events.
+    Timetable that schedules DAG runs at specific listed datetimes.
+
+    Suitable for predictable but truly irregular scheduling such as sporting events.
 
     :param event_dates: List of datetimes for the DAG to run at. Duplicates will be ignored. Must be finite
                         and of reasonable size as it will be loaded in its entirety.
@@ -51,7 +56,7 @@ class EventsTimetable(Timetable):
         self.event_dates = list(event_dates)  # Must be reversible and indexable
         if not presorted:
             # For long lists this could take a while, so only want to do it once
-            self.event_dates = sorted(self.event_dates)
+            self.event_dates.sort()
         self.restrict_to_events = restrict_to_events
         if description is None:
             self.description = (
