@@ -15,13 +15,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Utilities module for cli"""
+"""Utilities module for cli."""
 from __future__ import annotations
 
 import functools
 import logging
 import os
-import re
 import socket
 import sys
 import threading
@@ -32,7 +31,8 @@ from datetime import datetime
 from pathlib import Path
 from typing import TYPE_CHECKING, Callable, TypeVar, cast
 
-from sqlalchemy.orm import Session
+import re2
+from sqlalchemy import select
 
 from airflow import settings
 from airflow.exceptions import AirflowException, RemovedInAirflow3Warning
@@ -44,6 +44,8 @@ from airflow.utils.session import NEW_SESSION, provide_session
 T = TypeVar("T", bound=Callable)
 
 if TYPE_CHECKING:
+    from sqlalchemy.orm import Session
+
     from airflow.models.dag import DAG
 
 logger = logging.getLogger(__name__)
@@ -61,9 +63,10 @@ def _check_cli_args(args):
 def action_cli(func=None, check_db=True):
     def action_logging(f: T) -> T:
         """
-        Decorates function to execute function at the same time submitting action_logging
-        but in CLI context. It will call action logger callbacks twice,
-        one for pre-execution and the other one for post-execution.
+        Decorate function to execute function at the same time submitting action_logging but in CLI context.
+
+        It will call action logger callbacks twice, one for
+        pre-execution and the other one for post-execution.
 
         Action logger will be called with below keyword parameters:
             sub_command : name of sub-command
@@ -84,8 +87,7 @@ def action_cli(func=None, check_db=True):
         @functools.wraps(f)
         def wrapper(*args, **kwargs):
             """
-            An wrapper for cli functions. It assumes to have Namespace instance
-            at 1st positional argument
+            Wrap cli functions; assume Namespace instance as first positional argument.
 
             :param args: Positional argument. It assumes to have Namespace instance
                 at 1st positional argument
@@ -126,7 +128,8 @@ def action_cli(func=None, check_db=True):
 
 def _build_metrics(func_name, namespace):
     """
-    Builds metrics dict from function args
+    Build metrics dict from function args.
+
     It assumes that function arguments is from airflow.bin.cli module's function
     and has Namespace instance where it optionally contains "dag_id", "task_id",
     and "execution_date".
@@ -171,7 +174,7 @@ def _build_metrics(func_name, namespace):
 
 
 def process_subdir(subdir: str | None):
-    """Expands path to absolute by replacing 'DAGS_FOLDER', '~', '.', etc."""
+    """Expand path to absolute by replacing 'DAGS_FOLDER', '~', '.', etc."""
     if subdir:
         if not settings.DAGS_FOLDER:
             raise ValueError("DAGS_FOLDER variable in settings should be filled.")
@@ -181,7 +184,7 @@ def process_subdir(subdir: str | None):
 
 
 def get_dag_by_file_location(dag_id: str):
-    """Returns DAG of a given dag_id by looking up file location"""
+    """Return DAG of a given dag_id by looking up file location."""
     from airflow.models import DagBag, DagModel
 
     # Benefit is that logging from other dags in dagbag will not appear
@@ -215,37 +218,44 @@ def _search_for_dag_file(val: str | None) -> str | None:
     return None
 
 
-def get_dag(subdir: str | None, dag_id: str) -> DAG:
+def get_dag(subdir: str | None, dag_id: str, from_db: bool = False) -> DAG:
     """
-    Returns DAG of a given dag_id
+    Return DAG of a given dag_id.
 
-    First it we'll try to use the given subdir.  If that doesn't work, we'll try to
+    First we'll try to use the given subdir.  If that doesn't work, we'll try to
     find the correct path (assuming it's a file) and failing that, use the configured
     dags folder.
     """
     from airflow.models import DagBag
 
-    first_path = process_subdir(subdir)
-    dagbag = DagBag(first_path)
-    if dag_id not in dagbag.dags:
+    if from_db:
+        dagbag = DagBag(read_dags_from_db=True)
+    else:
+        first_path = process_subdir(subdir)
+        dagbag = DagBag(first_path)
+    dag = dagbag.get_dag(dag_id)
+    if not dag:
+        if from_db:
+            raise AirflowException(f"Dag {dag_id!r} could not be found in DagBag read from database.")
         fallback_path = _search_for_dag_file(subdir) or settings.DAGS_FOLDER
         logger.warning("Dag %r not found in path %s; trying path %s", dag_id, first_path, fallback_path)
         dagbag = DagBag(dag_folder=fallback_path)
-        if dag_id not in dagbag.dags:
+        dag = dagbag.get_dag(dag_id)
+        if not dag:
             raise AirflowException(
                 f"Dag {dag_id!r} could not be found; either it does not exist or it failed to parse."
             )
-    return dagbag.dags[dag_id]
+    return dag
 
 
 def get_dags(subdir: str | None, dag_id: str, use_regex: bool = False):
-    """Returns DAG(s) matching a given regex or dag_id"""
+    """Return DAG(s) matching a given regex or dag_id."""
     from airflow.models import DagBag
 
     if not use_regex:
         return [get_dag(subdir, dag_id)]
     dagbag = DagBag(process_subdir(subdir))
-    matched_dags = [dag for dag in dagbag.dags.values() if re.search(dag_id, dag.dag_id)]
+    matched_dags = [dag for dag in dagbag.dags.values() if re2.search(dag_id, dag.dag_id)]
     if not matched_dags:
         raise AirflowException(
             f"dag_id could not be found with regex: {dag_id}. Either the dag did not exist or "
@@ -256,10 +266,10 @@ def get_dags(subdir: str | None, dag_id: str, use_regex: bool = False):
 
 @provide_session
 def get_dag_by_pickle(pickle_id: int, session: Session = NEW_SESSION) -> DAG:
-    """Fetch DAG from the database using pickling"""
+    """Fetch DAG from the database using pickling."""
     from airflow.models import DagPickle
 
-    dag_pickle = session.query(DagPickle).filter(DagPickle.id == pickle_id).first()
+    dag_pickle = session.scalar(select(DagPickle).where(DagPickle.id == pickle_id)).first()
     if not dag_pickle:
         raise AirflowException(f"pickle_id could not be found in DagPickle.id list: {pickle_id}")
     pickle_dag = dag_pickle.pickle
@@ -267,7 +277,7 @@ def get_dag_by_pickle(pickle_id: int, session: Session = NEW_SESSION) -> DAG:
 
 
 def setup_locations(process, pid=None, stdout=None, stderr=None, log=None):
-    """Creates logging paths"""
+    """Create logging paths."""
     if not stderr:
         stderr = os.path.join(settings.AIRFLOW_HOME, f"airflow-{process}.err")
     if not stdout:
@@ -284,7 +294,7 @@ def setup_locations(process, pid=None, stdout=None, stderr=None, log=None):
 
 
 def setup_logging(filename):
-    """Creates log file handler for daemon process"""
+    """Create log file handler for daemon process."""
     root = logging.getLogger()
     handler = NonCachingFileHandler(filename)
     formatter = logging.Formatter(settings.SIMPLE_LOG_FORMAT)
@@ -297,7 +307,8 @@ def setup_logging(filename):
 
 def sigint_handler(sig, frame):
     """
-    Returns without error on SIGINT or SIGTERM signals in interactive command mode
+    Return without error on SIGINT or SIGTERM signals in interactive command mode.
+
     e.g. CTRL+C or kill <PID>
     """
     sys.exit(0)
@@ -305,8 +316,9 @@ def sigint_handler(sig, frame):
 
 def sigquit_handler(sig, frame):
     """
-    Helps debug deadlocks by printing stacktraces when this gets a SIGQUIT
-    e.g. kill -s QUIT <PID> or CTRL+\
+    Help debug deadlocks by printing stacktraces when this gets a SIGQUIT.
+
+    e.g. kill -s QUIT <PID> or CTRL+
     """
     print(f"Dumping stack traces for all threads in PID {os.getpid()}")
     id_to_name = {th.ident: th.name for th in threading.enumerate()}
@@ -329,7 +341,7 @@ class ColorMode:
 
 
 def should_use_colors(args) -> bool:
-    """Processes arguments and decides whether to enable color in output"""
+    """Process arguments and decide whether to enable color in output."""
     if args.color == ColorMode.ON:
         return True
     if args.color == ColorMode.OFF:
@@ -350,10 +362,7 @@ def should_ignore_depends_on_past(args) -> bool:
 
 
 def suppress_logs_and_warning(f: T) -> T:
-    """
-    Decorator to suppress logging and warning messages
-    in cli functions.
-    """
+    """Suppress logging and warning messages in cli functions."""
 
     @functools.wraps(f)
     def _wrapper(*args, **kwargs):
