@@ -14,38 +14,41 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import logging
-from typing import Dict, Iterator, List, Optional, Tuple
-
-try:
-    from functools import cached_property
-except ImportError:
-    from cached_property import cached_property
+import time
+from functools import cached_property
+from typing import TYPE_CHECKING, Iterator
 
 from airflow.configuration import conf
-from airflow.models import TaskInstance
 from airflow.utils.helpers import render_log_filename
 from airflow.utils.log.logging_mixin import ExternalLoggingMixin
+from airflow.utils.session import NEW_SESSION, provide_session
+from airflow.utils.state import TaskInstanceState
+
+if TYPE_CHECKING:
+    from sqlalchemy.orm.session import Session
+
+    from airflow.models.taskinstance import TaskInstance
 
 
 class TaskLogReader:
-    """Task log reader"""
+    """Task log reader."""
+
+    STREAM_LOOP_SLEEP_SECONDS = 0.5
+    """Time to sleep between loops while waiting for more logs"""
 
     def read_log_chunks(
-        self, ti: TaskInstance, try_number: Optional[int], metadata
-    ) -> Tuple[List[Tuple[Tuple[str, str]]], Dict[str, str]]:
+        self, ti: TaskInstance, try_number: int | None, metadata
+    ) -> tuple[list[tuple[tuple[str, str]]], dict[str, str]]:
         """
-        Reads chunks of Task Instance logs.
+        Read chunks of Task Instance logs.
 
         :param ti: The taskInstance
-        :type ti: TaskInstance
         :param try_number: If provided, logs for the given try will be returned.
             Otherwise, logs from all attempts are returned.
-        :type try_number: Optional[int]
         :param metadata: A dictionary containing information about how to read the task log
-        :type metadata: dict
-        :rtype: Tuple[List[Tuple[Tuple[str, str]]], Dict[str, str]]
 
         The following is an example of how to use this method to read log:
 
@@ -62,17 +65,13 @@ class TaskLogReader:
         metadata = metadatas[0]
         return logs, metadata
 
-    def read_log_stream(self, ti: TaskInstance, try_number: Optional[int], metadata: dict) -> Iterator[str]:
+    def read_log_stream(self, ti: TaskInstance, try_number: int | None, metadata: dict) -> Iterator[str]:
         """
-        Used to continuously read log to the end
+        Continuously read log to the end.
 
         :param ti: The Task Instance
-        :type ti: TaskInstance
         :param try_number: the task try number
-        :type try_number: Optional[int]
         :param metadata: A dictionary containing information about how to read the task log
-        :type metadata: dict
-        :rtype: Iterator[str]
         """
         if try_number is None:
             next_try = ti.next_try_number
@@ -80,44 +79,72 @@ class TaskLogReader:
         else:
             try_numbers = [try_number]
         for current_try_number in try_numbers:
-            metadata.pop('end_of_log', None)
-            metadata.pop('max_offset', None)
-            metadata.pop('offset', None)
-            while 'end_of_log' not in metadata or not metadata['end_of_log']:
+            metadata.pop("end_of_log", None)
+            metadata.pop("max_offset", None)
+            metadata.pop("offset", None)
+            metadata.pop("log_pos", None)
+            while True:
                 logs, metadata = self.read_log_chunks(ti, current_try_number, metadata)
                 for host, log in logs[0]:
-                    yield "\n".join([host, log]) + "\n"
+                    yield "\n".join([host or "", log]) + "\n"
+                if "end_of_log" not in metadata or (
+                    not metadata["end_of_log"]
+                    and ti.state not in (TaskInstanceState.RUNNING, TaskInstanceState.DEFERRED)
+                ):
+                    if not logs[0]:
+                        # we did not receive any logs in this loop
+                        # sleeping to conserve resources / limit requests on external services
+                        time.sleep(self.STREAM_LOOP_SLEEP_SECONDS)
+                else:
+                    break
 
     @cached_property
     def log_handler(self):
-        """Log handler, which is configured to read logs."""
-        logger = logging.getLogger('airflow.task')
-        task_log_reader = conf.get('logging', 'task_log_reader')
-        handler = next((handler for handler in logger.handlers if handler.name == task_log_reader), None)
-        return handler
+        """Get the log handler which is configured to read logs."""
+        task_log_reader = conf.get("logging", "task_log_reader")
+
+        def handlers():
+            """
+            Yield all handlers first from airflow.task logger then root logger.
+
+            Depending on whether we're in a running task, it could be in either of these locations.
+            """
+            yield from logging.getLogger("airflow.task").handlers
+            yield from logging.getLogger().handlers
+
+        return next((h for h in handlers() if h.name == task_log_reader), None)
 
     @property
     def supports_read(self):
         """Checks if a read operation is supported by a current log handler."""
-        return hasattr(self.log_handler, 'read')
+        return hasattr(self.log_handler, "read")
 
     @property
-    def supports_external_link(self):
+    def supports_external_link(self) -> bool:
         """Check if the logging handler supports external links (e.g. to Elasticsearch, Stackdriver, etc)."""
-        return isinstance(self.log_handler, ExternalLoggingMixin)
+        if not isinstance(self.log_handler, ExternalLoggingMixin):
+            return False
 
-    def render_log_filename(self, ti: TaskInstance, try_number: Optional[int] = None):
+        return self.log_handler.supports_external_link
+
+    @provide_session
+    def render_log_filename(
+        self,
+        ti: TaskInstance,
+        try_number: int | None = None,
+        *,
+        session: Session = NEW_SESSION,
+    ) -> str:
         """
-        Renders the log attachment filename
+        Render the log attachment filename.
 
         :param ti: The task instance
-        :type ti: TaskInstance
         :param try_number: The task try number
-        :type try_number: Optional[int]
-        :rtype: str
         """
-        filename_template = conf.get('logging', 'LOG_FILENAME_TEMPLATE')
+        dagrun = ti.get_dagrun(session=session)
         attachment_filename = render_log_filename(
-            ti=ti, try_number="all" if try_number is None else try_number, filename_template=filename_template
+            ti=ti,
+            try_number="all" if try_number is None else try_number,
+            filename_template=dagrun.get_log_template(session=session).filename,
         )
         return attachment_filename
