@@ -15,10 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-A TaskGroup is a collection of closely related tasks on the same DAG that should be grouped
-together when the DAG is displayed graphically.
-"""
+"""A collection of closely related tasks on the same DAG that should be grouped together visually."""
 from __future__ import annotations
 
 import copy
@@ -36,7 +33,7 @@ from airflow.exceptions import (
     DuplicateTaskIdFound,
     TaskAlreadyInTaskGroup,
 )
-from airflow.models.taskmixin import DAGNode, DependencyMixin
+from airflow.models.taskmixin import DAGNode
 from airflow.serialization.enums import DagAttributeTypes
 from airflow.utils.helpers import validate_group_key
 
@@ -48,13 +45,16 @@ if TYPE_CHECKING:
     from airflow.models.dag import DAG
     from airflow.models.expandinput import ExpandInput
     from airflow.models.operator import Operator
+    from airflow.models.taskmixin import DependencyMixin
     from airflow.utils.edgemodifier import EdgeModifier
 
 
 class TaskGroup(DAGNode):
     """
-    A collection of tasks. When set_downstream() or set_upstream() are called on the
-    TaskGroup, it is applied across all tasks within the group if necessary.
+    A collection of tasks.
+
+    When set_downstream() or set_upstream() are called on the TaskGroup, it is applied across
+    all tasks within the group if necessary.
 
     :param group_id: a unique, meaningful id for the TaskGroup. group_id must not conflict
         with group_id of TaskGroup or task_id of tasks in the DAG. Root TaskGroup has group_id
@@ -193,7 +193,7 @@ class TaskGroup(DAGNode):
 
     @property
     def is_root(self) -> bool:
-        """Returns True if this TaskGroup is the root TaskGroup. Otherwise False"""
+        """Returns True if this TaskGroup is the root TaskGroup. Otherwise False."""
         return not self.group_id
 
     @property
@@ -207,13 +207,17 @@ class TaskGroup(DAGNode):
             else:
                 yield child
 
-    def add(self, task: DAGNode) -> None:
+    def add(self, task: DAGNode) -> DAGNode:
         """Add a task to this TaskGroup.
 
         :meta private:
         """
         from airflow.models.abstractoperator import AbstractOperator
 
+        if TaskGroupContext.active:
+            if task.task_group and task.task_group != self:
+                task.task_group.children.pop(task.node_id, None)
+                task.task_group = self
         existing_tg = task.task_group
         if isinstance(task, AbstractOperator) and existing_tg is not None and existing_tg != self:
             raise TaskAlreadyInTaskGroup(task.node_id, existing_tg.node_id, self.node_id)
@@ -237,6 +241,7 @@ class TaskGroup(DAGNode):
                 raise AirflowException("Cannot add a non-empty TaskGroup")
 
         self.children[key] = task
+        return task
 
     def _remove(self, task: DAGNode) -> None:
         key = task.node_id
@@ -265,7 +270,7 @@ class TaskGroup(DAGNode):
         self, other: DependencyMixin, upstream: bool = True, edge_modifier: EdgeModifier | None = None
     ) -> None:
         """
-        Overrides TaskMixin.update_relative.
+        Override TaskMixin.update_relative.
 
         Update upstream_group_ids/downstream_group_ids/upstream_task_ids/downstream_task_ids
         accordingly so that we can reduce the number of edges when displaying Graph view.
@@ -313,6 +318,7 @@ class TaskGroup(DAGNode):
     ) -> None:
         """
         Call set_upstream/set_downstream for all root/leaf tasks within this TaskGroup.
+
         Update upstream_group_ids/downstream_group_ids/upstream_task_ids/downstream_task_ids.
         """
         if not isinstance(task_or_task_list, Sequence):
@@ -336,7 +342,7 @@ class TaskGroup(DAGNode):
         TaskGroupContext.pop_context_managed_task_group()
 
     def has_task(self, task: BaseOperator) -> bool:
-        """Returns True if this TaskGroup or its children TaskGroups contains the given task."""
+        """Return True if this TaskGroup or its children TaskGroups contains the given task."""
         if task.task_id in self.children:
             return True
 
@@ -344,37 +350,49 @@ class TaskGroup(DAGNode):
 
     @property
     def roots(self) -> list[BaseOperator]:
-        """Required by TaskMixin"""
+        """Required by TaskMixin."""
         return list(self.get_roots())
 
     @property
     def leaves(self) -> list[BaseOperator]:
-        """Required by TaskMixin"""
+        """Required by TaskMixin."""
         return list(self.get_leaves())
 
     def get_roots(self) -> Generator[BaseOperator, None, None]:
-        """
-        Returns a generator of tasks that are root tasks, i.e. those with no upstream
-        dependencies within the TaskGroup.
-        """
-        for task in self:
-            if not any(self.has_task(parent) for parent in task.get_direct_relatives(upstream=True)):
+        """Return a generator of tasks with no upstream dependencies within the TaskGroup."""
+        tasks = list(self)
+        ids = {x.task_id for x in tasks}
+        for task in tasks:
+            if task.upstream_task_ids.isdisjoint(ids):
                 yield task
 
     def get_leaves(self) -> Generator[BaseOperator, None, None]:
-        """
-        Returns a generator of tasks that are leaf tasks, i.e. those with no downstream
-        dependencies within the TaskGroup
-        """
-        for task in self:
-            if not any(self.has_task(child) for child in task.get_direct_relatives(upstream=False)):
-                yield task
+        """Return a generator of tasks with no downstream dependencies within the TaskGroup."""
+        tasks = list(self)
+        ids = {x.task_id for x in tasks}
+
+        def recurse_for_first_non_teardown(task):
+            for upstream_task in task.upstream_list:
+                if upstream_task.task_id not in ids:
+                    # upstream task is not in task group
+                    continue
+                elif upstream_task.is_teardown:
+                    yield from recurse_for_first_non_teardown(upstream_task)
+                elif task.is_teardown and upstream_task.is_setup:
+                    # don't go through the teardown-to-setup path
+                    continue
+                else:
+                    yield upstream_task
+
+        for task in tasks:
+            if task.downstream_task_ids.isdisjoint(ids):
+                if not task.is_teardown:
+                    yield task
+                else:
+                    yield from recurse_for_first_non_teardown(task)
 
     def child_id(self, label):
-        """
-        Prefix label with group_id if prefix_group_id is True. Otherwise return the label
-        as-is.
-        """
+        """Prefix label with group_id if prefix_group_id is True. Otherwise return the label as-is."""
         if self.prefix_group_id:
             group_id = self.group_id
             if group_id:
@@ -385,6 +403,8 @@ class TaskGroup(DAGNode):
     @property
     def upstream_join_id(self) -> str:
         """
+        Creates a unique ID for upstream dependencies of this TaskGroup.
+
         If this TaskGroup has immediate upstream TaskGroups or tasks, a proxy node called
         upstream_join_id will be created in Graph view to join the outgoing edges from this
         TaskGroup to reduce the total number of edges needed to be displayed.
@@ -394,6 +414,8 @@ class TaskGroup(DAGNode):
     @property
     def downstream_join_id(self) -> str:
         """
+        Creates a unique ID for downstream dependencies of this TaskGroup.
+
         If this TaskGroup has immediate downstream TaskGroups or tasks, a proxy node called
         downstream_join_id will be created in Graph view to join the outgoing edges from this
         TaskGroup to reduce the total number of edges needed to be displayed.
@@ -401,7 +423,7 @@ class TaskGroup(DAGNode):
         return f"{self.group_id}.downstream_join_id"
 
     def get_task_group_dict(self) -> dict[str, TaskGroup]:
-        """Returns a flat dictionary of group_id: TaskGroup"""
+        """Return a flat dictionary of group_id: TaskGroup."""
         task_group_map = {}
 
         def build_map(task_group):
@@ -417,19 +439,31 @@ class TaskGroup(DAGNode):
         return task_group_map
 
     def get_child_by_label(self, label: str) -> DAGNode:
-        """Get a child task/TaskGroup by its label (i.e. task_id/group_id without the group_id prefix)"""
+        """Get a child task/TaskGroup by its label (i.e. task_id/group_id without the group_id prefix)."""
         return self.children[self.child_id(label)]
 
     def serialize_for_task_group(self) -> tuple[DagAttributeTypes, Any]:
-        """Required by DAGNode."""
+        """Serialize task group; required by DAGNode."""
         from airflow.serialization.serialized_objects import TaskGroupSerialization
 
         return DagAttributeTypes.TASK_GROUP, TaskGroupSerialization.serialize_task_group(self)
 
+    def hierarchical_alphabetical_sort(self):
+        """
+        Sort children in hierarchical alphabetical order.
+
+        - groups in alphabetical order first
+        - tasks in alphabetical order after them.
+
+        :return: list of tasks in hierarchical alphabetical order
+        """
+        return sorted(
+            self.children.values(), key=lambda node: (not isinstance(node, TaskGroup), node.node_id)
+        )
+
     def topological_sort(self, _include_subdag_tasks: bool = False):
         """
-        Sorts children in topographical order, such that a task comes after any of its
-        upstream dependencies.
+        Sorts children in topographical order, such that a task comes after any of its upstream dependencies.
 
         :return: list of tasks in topological order
         """
@@ -442,14 +476,14 @@ class TaskGroup(DAGNode):
         graph_sorted: list[DAGNode] = []
 
         # special case
-        if len(self.children) == 0:
+        if not self.children:
             return graph_sorted
 
         # Run until the unsorted graph is empty.
         while graph_unsorted:
             # Go through each of the node/edges pairs in the unsorted graph. If a set of edges doesn't contain
             # any nodes that haven't been resolved, that is, that are still in the unsorted graph, remove the
-            # pair from the unsorted graph, and append it to the sorted graph. Note here that by using using
+            # pair from the unsorted graph, and append it to the sorted graph. Note here that by using
             # the values() method for iterating, a copy of the unsorted graph is used, allowing us to modify
             # the unsorted graph as we move through it.
             #
@@ -500,7 +534,7 @@ class TaskGroup(DAGNode):
             group = group.task_group
 
     def iter_tasks(self) -> Iterator[AbstractOperator]:
-        """Returns an iterator of the child tasks."""
+        """Return an iterator of the child tasks."""
         from airflow.models.abstractoperator import AbstractOperator
 
         groups_to_visit = [self]
@@ -532,8 +566,6 @@ class MappedTaskGroup(TaskGroup):
     def __init__(self, *, expand_input: ExpandInput, **kwargs: Any) -> None:
         super().__init__(**kwargs)
         self._expand_input = expand_input
-        for op, _ in expand_input.iter_references():
-            self.set_upstream(op)
 
     def iter_mapped_dependencies(self) -> Iterator[Operator]:
         """Upstream dependencies that provide XComs used by this mapped task group."""
@@ -544,7 +576,8 @@ class MappedTaskGroup(TaskGroup):
 
     @cache
     def get_parse_time_mapped_ti_count(self) -> int:
-        """Number of instances a task in this group should be mapped to, when a DAG run is created.
+        """
+        Return the Number of instances a task in this group should be mapped to, when a DAG run is created.
 
         This only considers literal mapped arguments, and would return *None*
         when any non-literal values are used for mapping.
@@ -563,7 +596,8 @@ class MappedTaskGroup(TaskGroup):
         )
 
     def get_mapped_ti_count(self, run_id: str, *, session: Session) -> int:
-        """Number of instances a task in this group should be mapped to at run time.
+        """
+        Return the number of instances a task in this group should be mapped to at run time.
 
         This considers both literal and non-literal mapped arguments, and the
         result is therefore available when all depended tasks have finished. The
@@ -584,10 +618,16 @@ class MappedTaskGroup(TaskGroup):
             (g._expand_input.get_total_map_length(run_id, session=session) for g in groups),
         )
 
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        for op, _ in self._expand_input.iter_references():
+            self.set_upstream(op)
+        super().__exit__(exc_type, exc_val, exc_tb)
+
 
 class TaskGroupContext:
     """TaskGroup context is used to keep the current TaskGroup when TaskGroup is used as ContextManager."""
 
+    active: bool = False
     _context_managed_task_group: TaskGroup | None = None
     _previous_context_managed_task_groups: list[TaskGroup] = []
 
@@ -597,6 +637,7 @@ class TaskGroupContext:
         if cls._context_managed_task_group:
             cls._previous_context_managed_task_groups.append(cls._context_managed_task_group)
         cls._context_managed_task_group = task_group
+        cls.active = True
 
     @classmethod
     def pop_context_managed_task_group(cls) -> TaskGroup | None:
@@ -606,6 +647,7 @@ class TaskGroupContext:
             cls._context_managed_task_group = cls._previous_context_managed_task_groups.pop()
         else:
             cls._context_managed_task_group = None
+        cls.active = False
         return old_task_group
 
     @classmethod
@@ -623,21 +665,24 @@ class TaskGroupContext:
 
 
 def task_group_to_dict(task_item_or_group):
-    """
-    Create a nested dict representation of this TaskGroup and its children used to construct
-    the Graph.
-    """
+    """Create a nested dict representation of this TaskGroup and its children used to construct the Graph."""
     from airflow.models.abstractoperator import AbstractOperator
 
-    if isinstance(task_item_or_group, AbstractOperator):
+    if isinstance(task := task_item_or_group, AbstractOperator):
+        setup_teardown_type = {}
+        if task.is_setup is True:
+            setup_teardown_type["setupTeardownType"] = "setup"
+        elif task.is_teardown is True:
+            setup_teardown_type["setupTeardownType"] = "teardown"
         return {
-            "id": task_item_or_group.task_id,
+            "id": task.task_id,
             "value": {
-                "label": task_item_or_group.label,
-                "labelStyle": f"fill:{task_item_or_group.ui_fgcolor};",
-                "style": f"fill:{task_item_or_group.ui_color};",
+                "label": task.label,
+                "labelStyle": f"fill:{task.ui_fgcolor};",
+                "style": f"fill:{task.ui_color};",
                 "rx": 5,
                 "ry": 5,
+                **setup_teardown_type,
             },
         }
     task_group = task_item_or_group
